
:orphan:

.. _sphx_glr_sg_execution_times:


Computation times
=================
**00:01.212** total execution time for 36 files **from all galleries**:

.. container::

  .. raw:: html

    <style scoped>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    </style>
    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script type="text/javascript" class="init">
    $(document).ready( function () {
        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
    } );
    </script>

  .. list-table::
   :header-rows: 1
   :class: table table-striped sg-datatable

   * - Example
     - Time
     - Mem (MB)
   * - :ref:`sphx_glr_gallery_plot_ete4.py` (``../../gallery/plot_ete4.py``)
     - 00:01.212
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_animation.py` (``../../gallery/plot_animation.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_basic.py` (``../../gallery/plot_basic.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_big_curves.py` (``../../gallery/plot_big_curves.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_biopython_tree.py` (``../../gallery/plot_biopython_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_chess_masters.py` (``../../gallery/plot_chess_masters.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_cliques.py` (``../../gallery/plot_cliques.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_cluster_layout.py` (``../../gallery/plot_cluster_layout.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_cogent3_tree.py` (``../../gallery/plot_cogent3_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_company_structure.py` (``../../gallery/plot_company_structure.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_complex.py` (``../../gallery/plot_complex.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_dag.py` (``../../gallery/plot_dag.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_directed.py` (``../../gallery/plot_directed.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_edit_artists.py` (``../../gallery/plot_edit_artists.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_four_grids.py` (``../../gallery/plot_four_grids.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_grouping.py` (``../../gallery/plot_grouping.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_house.py` (``../../gallery/plot_house.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_knuth_miles.py` (``../../gallery/plot_knuth_miles.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_labels_and_colors.py` (``../../gallery/plot_labels_and_colors.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_loops.py` (``../../gallery/plot_loops.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_max_bipartite_matching.py` (``../../gallery/plot_max_bipartite_matching.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_minimum_spanning_trees.py` (``../../gallery/plot_minimum_spanning_trees.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_mouse_hover.py` (``../../gallery/plot_mouse_hover.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_multipartite_layout.py` (``../../gallery/plot_multipartite_layout.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_parallel_igraph_networkx.py` (``../../gallery/plot_parallel_igraph_networkx.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_ports.py` (``../../gallery/plot_ports.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_shortest_path.py` (``../../gallery/plot_shortest_path.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_simple_networkx.py` (``../../gallery/plot_simple_networkx.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_simple_path.py` (``../../gallery/plot_simple_path.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_skbio_tree.py` (``../../gallery/plot_skbio_tree.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_style.py` (``../../gallery/plot_style.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_traveling_salesman.py` (``../../gallery/plot_traveling_salesman.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_tree_node_background.py` (``../../gallery/plot_tree_node_background.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_trees_of_trees.py` (``../../gallery/plot_trees_of_trees.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_voronoi.py` (``../../gallery/plot_voronoi.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_gallery_plot_with_colorbar.py` (``../../gallery/plot_with_colorbar.py``)
     - 00:00.000
     - 0.0
